@@ -23,7 +23,7 @@ c = Configuration()
 template = """\
 __version__ = version = {version!r}
 __version_tuple__ = version_tuple = {version_tuple!r}
-__sha__ = {scm_version.node!r}
+__sha__ = {scm_version.short_node!r}
 """
 
 
@@ -55,7 +55,9 @@ def assert_root(monkeypatch: pytest.MonkeyPatch, expected_root: str) -> None:
 
     def assertion(config: Configuration) -> ScmVersion:
         assert config.absolute_root == expected_root
-        return ScmVersion("1.0", config=config)
+        from packaging.version import Version
+
+        return ScmVersion(Version("1.0"), config=config)
 
     monkeypatch.setattr(setuptools_scm._get_version_impl, "parse_version", assertion)
 
@@ -104,7 +106,7 @@ setup(use_scm_version={"fallback_version": "12.34"})
 
 
 def test_empty_pretend_version(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
-    monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
+    # monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
     monkeypatch.setenv("SETUPTOOLS_SCM_PRETEND_VERSION", "")
     p = tmp_path / "sub/package"
     p.mkdir(parents=True)
@@ -184,17 +186,30 @@ def test_dump_version(tmp_path: Path) -> None:
     scm_version = meta("1.0", distance=42, config=c)
     dump_version(tmp_path, version, "first.py", scm_version=scm_version)
     lines = read("first.py").splitlines()
-    assert lines[-2:] == [
+    assert lines[-4:] == [
         "__version__ = version = '1.0.dev42'",
         "__version_tuple__ = version_tuple = (1, 0, 'dev42')",
+        "",
+        "__commit_id__ = commit_id = None",
+    ]
+
+    version = "1.0.1"
+    scm_version = meta("1.0.1", node="g4ac9d2c", config=c)
+    dump_version(tmp_path, version, "second.py", scm_version=scm_version)
+    lines = read("second.py").splitlines()
+    assert lines[-4:] == [
+        "__version__ = version = '1.0.1'",
+        "__version_tuple__ = version_tuple = (1, 0, 1)",
+        "",
+        "__commit_id__ = commit_id = 'g4ac9d2c'",
     ]
 
     version = "1.0.1+g4ac9d2c"
     scm_version = meta("1.0.1", node="g4ac9d2c", config=c)
     dump_version(
-        tmp_path, version, "second.py", scm_version=scm_version, template=template
+        tmp_path, version, "third.py", scm_version=scm_version, template=template
     )
-    lines = read("second.py").splitlines()
+    lines = read("third.py").splitlines()
     assert "__version__ = version = '1.0.1+g4ac9d2c'" in lines
     assert "__version_tuple__ = version_tuple = (1, 0, 1, 'g4ac9d2c')" in lines
     assert "__sha__ = 'g4ac9d2c'" in lines
@@ -204,9 +219,9 @@ def test_dump_version(tmp_path: Path) -> None:
         "1.2.3", node="gb366d8b", distance=18, node_date=date(2021, 4, 15), config=c
     )
     dump_version(
-        tmp_path, version, "third.py", scm_version=scm_version, template=template
+        tmp_path, version, "fourth.py", scm_version=scm_version, template=template
     )
-    lines = read("third.py").splitlines()
+    lines = read("fourth.py").splitlines()
     assert "__version__ = version = '1.2.3.dev18+gb366d8b.d20210415'" in lines
     assert (
         "__version_tuple__ = version_tuple = (1, 2, 3, 'dev18', 'gb366d8b.d20210415')"
@@ -216,7 +231,7 @@ def test_dump_version(tmp_path: Path) -> None:
 
     import ast
 
-    ast.parse(read("third.py"))
+    ast.parse(read("fourth.py"))
 
 
 def test_parse_plain_fails(recwarn: pytest.WarningsRecorder) -> None:
@@ -237,6 +252,18 @@ def test_custom_version_cls() -> None:
         def __repr__(self) -> str:
             return f"hello,{self.version}"
 
+        @property
+        def public(self) -> str:
+            """The public portion of the version (without local part)."""
+            return self.version.split("+")[0]
+
+        @property
+        def local(self) -> str | None:
+            """The local version segment."""
+            if "+" in self.version:
+                return self.version.split("+", 1)[1]
+            return None
+
     # you can not use normalize=False and version_cls at the same time
     with pytest.raises(
         ValueError,
